/* Copyright(C) 2017-2024, HJD (https://github.com/hjdhjd). All rights reserved.
 *
 * util.ts: Useful utility functions when writing TypeScript.
 */
// Retry an operation until we're successful.
export async function retry(operation, retryInterval, totalRetries) {
    if ((totalRetries !== undefined) && (totalRetries < 0)) {
        return false;
    }
    // Try the operation that was requested.
    if (!(await operation())) {
        // If the operation wasn't successful, let's sleep for the requested interval and try again.
        await sleep(retryInterval);
        return retry(operation, retryInterval, (totalRetries === undefined) ? undefined : totalRetries--);
    }
    // We were successful - we're done.
    return true;
}
// Run a promise with a guaranteed timeout to complete.
export async function runWithTimeout(promise, timeout) {
    const timeoutPromise = new Promise((resolve) => setTimeout(() => resolve(null), timeout));
    return Promise.race([promise, timeoutPromise]);
}
// Emulate a sleep function.
export async function sleep(sleepTimer) {
    return new Promise(resolve => setTimeout(resolve, sleepTimer));
}
// Validate a name according to HomeKit naming conventions.
export function validateName(name) {
    // Validate our names using [HomeKit's naming rulesets](https://developer.apple.com/design/human-interface-guidelines/homekit#Help-people-choose-useful-names):
    //
    // - Use only alphanumeric, space, and apostrophe characters.
    // - Start and end with an alphabetic or numeric character.
    // - Don’t include emojis.
    //
    // Invalid characters will be replaced by a space, and multiple spaces will be squashed.
    return name.replace(/[^\p{L}\p{N} ']+/gu, " ").replace(/\s+/g, " ").trim();
}
//# sourceMappingURL=util.js.map